@@ -37,9 +37,9 @@ mlxplore <- function(model,parameter=NULL,output=NULL,group=NULL,treatment=NULL)
   #  mlxplore.R was developed by Marc Lavielle and the Inria Popix team for the DDMoRe project. 
   # ########################################################################################  
   initMlxLibrary()
-  session <- Sys.getenv("session.mlxplore")
+  session=Sys.getenv("session.simulx")
   if (is.na(file.info(session)$isdir))
-    stop("You need to provide the path of Mlxplore in the file \"initMlR.R\"")
+    stop("You need to provide the path of Mlxplore in the file \"initMlR.R\"", call.=FALSE)
   
   
   Sys.setenv(LIXOFT_HOME=session)
@@ -151,8 +151,9 @@ mlxplore <- function(model,parameter=NULL,output=NULL,group=NULL,treatment=NULL)
   
   #--------------------------------------------------------
   
-  str=paste0('"',session,'/lib/mlxPlore" --multiple-windows=true --project=',tmproject)  
-   system(str, wait=F, invisible=F)
+  str=paste0('"',session,'/lib/mlxPlore" --project=',tmproject)  
+  #str=paste0('"',session,'/lib/mlxPlore" --multiple-windows=true --project=',tmproject)  
+  system(str, wait=F, invisible=F)
 #   system(str, wait=F)
   
 }
