@@ -10,7 +10,7 @@
 #' @param level the largest interval (i.e. the difference between the lowest and the highest percentile).
 #' @param plot if \code{TRUE} the empirical distribution is displayed, if \code{FALSE}
 #' the values are returned
-#' @param color a color to be used for the plots (default="purple")
+#' @param color a color to be used for the plots (default="#9a35ff")
 #' @param group  variable to be used for defining groups (by default, \samp{group} is used when it exists)
 #' @param facet  makes subplots for different groups if \code{TRUE} 
 #' @param labels  vector of strings 
@@ -80,7 +80,7 @@
 #' @importFrom ggplot2 ggplot geom_point theme aes geom_line xlab ylab facet_wrap facet_grid
 #' @importFrom stats quantile 
 #' @export         
-prctilemlx <- function(r,col=NULL, number=8, level=80, plot=TRUE, color="purple",
+prctilemlx <- function(r,col=NULL, number=8, level=80, plot=TRUE, color="#9a35ff",
                        group=NULL, facet=TRUE, labels=NULL, band=NULL)
 {
   
@@ -129,10 +129,12 @@ prctilemlx <- function(r,col=NULL, number=8, level=80, plot=TRUE, color="purple"
   }
   
   id <- r[,col[1]]
-  n <- length(which(id==id[1]))
   d <- col[3]
+  t <- unique(r[,col[2]])
+  n <- length(t)
   
-  t <- r[,col[2]][1:n]
+  # n <- length(which(id==id[1]))
+  # t <- r[,col[2]][1:n]
   x.label=names(r)[col[2]]
   y.label=names(r)[col[3]]
   
